====================================
Submarine: Python Subtitle Converter
====================================

* Python 2 / 3 compatible subtitle converter.
* Converts SAMI or SubRip style subtitles to a WEBVTT format.

Requirements
------------

* Python 2.7.x / 3.3.x or later (Will probably work on 2.6.x and 3.2.x)  
* chardet 2.2.1 or later

Installation
------------

First, you'll need to install `chardet`::
	
	pip install chardet

Then, install from `PyPI <https://pypi.python.org/pypi/submarine>`_ via `pip`::

	pip install submarine


Commandline Usage
-----------------

In any shell or terminal emulator::

    submarine filename.srt path_to_file.vtt
    submarine filename.smi path_to_file.vtt

If no path_to_file is given, output directory will be the origin of source file.

License
-------

Copyright (c) 2014, TNTcrowd Co., Ltd.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this
list of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
